;; Generated package description from kind-icon.el  -*- no-byte-compile: t -*-
(define-package "kind-icon" "0.2.0" "Completion kind icons" '((emacs "27.1") (svg-lib "0")) :commit "47b72281e2d339926b192574ccade8e5ca14c282" :authors '(("J.D. Smith" . "jdtsmith@gmail.com")) :maintainer '("J.D. Smith" . "jdtsmith@gmail.com") :keywords '("completion") :url "https://github.com/jdtsmith/kind-icon")
